.. _installation:

Installation
==============

Dependencies
------------
Jazzhands requires ``numpy`` package. It must be installed or the package won't work properly.

Optional dependencies are: 

With conda
----------

To install Jazzhands with released latest version of conda, use the following command::
        
    conda install jazzhands
    
With pip
--------

To install Jazzhands using pip, run the following code::

    pip install jazzhands
    
Pip will automatically installs the dependency package ``numpy`` also. To install Jazzhands without dependencies, run the code below::
    pip install --no-deps jazzhands

